import {Component} from '@angular/core';
import {FormBuilder, FormGroup, FormsModule, ReactiveFormsModule, ValidatorFn, Validators} from "@angular/forms";
import {NavigationService} from "@service/navigation.service";
import SetupService from "@api/v1/setup.service";
import {of} from "rxjs";
import {MatError, MatFormField, MatLabel} from "@angular/material/form-field";
import {MatInput} from "@angular/material/input";
import {MatTooltip} from "@angular/material/tooltip";
import SecurityService from "@api/v1/securityService";

@Component({
  selector: 'app-two-factor',
  imports: [
    FormsModule,
    ReactiveFormsModule,
    MatError,
    MatFormField,
    MatInput,
    MatLabel,
    MatTooltip
  ],
  templateUrl: './two-factor.component.html',
  providers: [SecurityService]
})
export class TwoFactorComponent {
  protected twoFactorForm!: FormGroup;
  protected secret!: string;
  protected totpImage!: string;

  constructor(
    private navigationService: NavigationService, private formBuilder: FormBuilder, api: SetupService, apiSecurity: SecurityService) {
    api.generateTotpKey().subscribe(x => {
      this.secret = x;
    });
    api.adminConfiguration().subscribe(x => {
      this.totpImage = apiSecurity.generateTotpQrCode(this.secret, x.username);
      if (x.twoFactorAuthenticatorEnabled)
        this.navigationService.triggerAutoSkip(this.navigationService.skipButtonAction);
    });

    this.navigationService.setSkipButtonState(true);
    this.navigationService.skipButtonAction = () => of(true);

    const validators: ValidatorFn[] = [Validators.required, Validators.minLength(6), Validators.pattern('^[0-9]*$')];
    this.twoFactorForm = this.formBuilder.group({
      code: ['', validators],
    });

    this.navigationService.nextButtonAction = () => api.verifyTotp(this.twoFactorForm.get('code')?.value);
    this.navigationService.setNextButtonState(this.twoFactorForm.valid);
    this.twoFactorForm.valueChanges.subscribe(() => {
      this.navigationService.setNextButtonState(this.twoFactorForm.valid);
    });
  }
}
