import {Component} from '@angular/core';
import {NavigationService} from "@service/navigation.service";
import {MatFormFieldModule} from "@angular/material/form-field";
import {MatInput} from "@angular/material/input";
import {FormControl, ReactiveFormsModule, Validators} from "@angular/forms";
import SetupService from "@api/v1/setup.service";
import {environment} from "@environment";
import {AvailableVersion} from "@api/api.service";
import {of} from "rxjs";

@Component({
  selector: 'app-welcome',
  standalone: true,
  imports: [
    MatFormFieldModule,
    MatInput,
    ReactiveFormsModule
  ],
  templateUrl: './welcome.component.html'
})

export class WelcomeComponent {
  protected tokenControl = new FormControl('', [
    Validators.required,
    Validators.pattern(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{4}|[A-Za-z0-9+\/]{3}=|[A-Za-z0-9+\/]{2}={2})$/),
    Validators.minLength(16)
  ]);

  protected apiToGetToken: string = environment.apiUrl;

  constructor(private navigationService: NavigationService, private api: SetupService) {
    this.apiToGetToken += AvailableVersion[this.api.version];

    this.navigationService.nextButtonAction = () => this.api.checkToken(this.tokenControl.value ?? '');

    this.tokenControl.valueChanges.subscribe(() => {
      this.navigationService.setNextButtonState(this.tokenControl.valid);
    });

    this.api.isConfiguredToken().subscribe(data => {
      console.log(data);
      if (!data)
        return;

      this.navigationService.setSkipButtonState(true);
      this.navigationService.skipButtonAction = () => of(true);
      this.navigationService.triggerAutoSkip(this.navigationService.skipButtonAction);
    });
  }
}
